<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="2.0" 
                xmlns:fp="http://example.org/fpCounting" 
				xmlns:xs="http://www.w3.org/2001/XMLSchema" exclude-result-prefixes="fp xs">
				
    <!--
       Common Function point report stylesheet functionality.
    -->	
				
	<!-- Count Data function points -->
	<xsl:function name="fp:getDataFPCount" as="xs:double">
	   <xsl:param name="dataCountNode" as="element()?"/>
	   
	   <xsl:variable name="ilfComplexityList" as="xs:string*">
	      <xsl:for-each select="$dataCountNode/ILF/item">
		     <xsl:value-of select="fp:getILF_EIF_Complexity(@ret, @det)"/>
		  </xsl:for-each>
	   </xsl:variable>
	   <xsl:variable name="eifComplexityList" as="xs:string*">
	      <xsl:for-each select="$dataCountNode/EIF/item">		     
			 <xsl:value-of select="fp:getILF_EIF_Complexity(@ret, @det)"/>
		  </xsl:for-each>
	   </xsl:variable>
	   <xsl:sequence select="sum(for $x in $ilfComplexityList return $fpRefData/DataFunc/ILF/fpNum/*[name() = $x]) +  
	                         sum(for $x in $eifComplexityList return $fpRefData/DataFunc/EIF/fpNum/*[name() = $x])"/>
	</xsl:function>
	
	<!-- Find complexity of a given ILF or EIF -->
	<xsl:function name="fp:getILF_EIF_Complexity" as="xs:string">
	   <xsl:param name="retNum" as="xs:integer"/>
	   <xsl:param name="detNum" as="xs:integer"/>

	   <xsl:sequence select="$fpRefData/DataFunc/complexityForCount/item
			                         [((xs:integer($retNum) ge xs:integer(@ret0)) and (xs:integer($retNum) le xs:integer((if (@ret1 = 'unbounded') then $retNum else @ret1))))
									    and 
									  ((xs:integer($detNum) ge xs:integer(@det0)) and (xs:integer($detNum) le xs:integer((if (@det1 = 'unbounded') then $detNum else @det1))))]"/>	   
	</xsl:function>
	
	<!-- Count Transaction function points -->
	<xsl:function name="fp:getTxnFPCount" as="xs:double">
	   <xsl:param name="txnCountNode" as="element()?"/>
	   
	   <!-- EI Function Points -->
	   <xsl:variable name="eiComplexityList" as="xs:string*">
	      <xsl:for-each select="$txnCountNode/EI/item">
		      <xsl:variable name="ftrNum" select="@ftr"/>
			  <xsl:variable name="detNum" select="@det"/>
		      <xsl:value-of select="$fpRefData/TxnFunc/EI/complexityForCount/item
			                          [((xs:integer($ftrNum) ge xs:integer(@ftr0)) and (xs:integer($ftrNum) le xs:integer((if (@ftr1 = 'unbounded') then $ftrNum else @ftr1))))
							 		     and 
									   ((xs:integer($detNum) ge xs:integer(@det0)) and (xs:integer($detNum) le xs:integer((if (@det1 = 'unbounded') then $detNum else @det1))))]"/>
		  </xsl:for-each>
	   </xsl:variable>
	   
	   <!-- EO Function Points -->
	   <xsl:variable name="eoComplexityList" as="xs:string*">
	      <xsl:for-each select="$txnCountNode/EO/item">
		      <xsl:variable name="ftrNum" select="@ftr"/>
			  <xsl:variable name="detNum" select="@det"/>
		      <xsl:value-of select="$fpRefData/TxnFunc/EO_EQ/complexityForCount/item
			                          [((xs:integer($ftrNum) ge xs:integer(@ftr0)) and (xs:integer($ftrNum) le xs:integer((if (@ftr1 = 'unbounded') then $ftrNum else @ftr1))))
							 		     and 
									   ((xs:integer($detNum) ge xs:integer(@det0)) and (xs:integer($detNum) le xs:integer((if (@det1 = 'unbounded') then $detNum else @det1))))]"/>
		  </xsl:for-each>
	   </xsl:variable>
	   
	   <!-- EQ Function Points -->
	   <xsl:variable name="eqComplexityList" as="xs:string*">
	      <xsl:for-each select="$txnCountNode/EQ/item">
		      <xsl:variable name="ftrNum" select="@ftr"/>
			  <xsl:variable name="detNum" select="@det"/>
		      <xsl:value-of select="$fpRefData/TxnFunc/EO_EQ/complexityForCount/item
			                          [((xs:integer($ftrNum) ge xs:integer(@ftr0)) and (xs:integer($ftrNum) le xs:integer((if (@ftr1 = 'unbounded') then $ftrNum else @ftr1))))
							 		     and 
									   ((xs:integer($detNum) ge xs:integer(@det0)) and (xs:integer($detNum) le xs:integer((if (@det1 = 'unbounded') then $detNum else @det1))))]"/>
		  </xsl:for-each>
	   </xsl:variable>
	   
	   <xsl:sequence select="sum(for $x in $eiComplexityList return $fpRefData/TxnFunc/fpNum[@type = 'EI_EQ']/*[name() = $x]) +  
	                         sum(for $x in $eoComplexityList return $fpRefData/TxnFunc/fpNum[@type = 'EO']/*[name() = $x]) +
							 sum(for $x in $eqComplexityList return $fpRefData/TxnFunc/fpNum[@type = 'EI_EQ']/*[name() = $x])"/>
	   
	</xsl:function>
	
	<!--
	   Prints an empty table row.
	-->
	<xsl:template name="EmptyRow">
	   <tr>
	      <td colspan="3">&#160;</td>
	   </tr>
	</xsl:template>
	
</xsl:stylesheet>