<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="2.0" 
                xmlns:fp="http://example.org/fpCounting" 
				xmlns:xs="http://www.w3.org/2001/XMLSchema" exclude-result-prefixes="fp xs">
				
	<!--
       Generates Function Point report, for projects of kind "new development".
    -->

    <xsl:output method="html"/>
	
	<xsl:include href="commonfp.xsl"/>
	
	<xsl:variable name="fpRefData" select="document('fpRefData.xml')/FPRefData"/>
	
	<!--
	   Main stylesheet template.
	-->
	<xsl:template match="FPCountingData">
	   <html>
	      <head>
		     <title>FP counting results</title>
		  </head>
		  <body>
		     <h2>Project: <xsl:value-of select="@project"/></h2>
			 <xsl:variable name="applnCountResults">
		        <xsl:apply-templates select="application"/>
			 </xsl:variable>
			 <xsl:for-each select="$applnCountResults/table">
			    <xsl:copy-of select="."/>
				<u>Application Unadjusted FP count:</u><xsl:text> </xsl:text><xsl:value-of select="tr[4]/td[3] + tr[5]/td[3]"/>
				<br/><br/>
				<xsl:text>----------------------------------------</xsl:text>
				<br/><br/>
			 </xsl:for-each>
			 <xsl:variable name="unAdjFp" select="sum($applnCountResults/table/tr[4]/td[3]) +
			                                      sum($applnCountResults/table/tr[5]/td[3])"/>
             <b>Total Unadjusted Function Points:</b><xsl:text> </xsl:text><xsl:value-of select="$unAdjFp"/>																						              
             <xsl:if test="GSC">
               <br/><br/>
			   <xsl:variable name="vaf" select="(sum(GSC/fact) * 0.01) + 0.65"/>
			   <b>Value Adjustment Factor:</b><xsl:text> </xsl:text><xsl:value-of select="$vaf"/>
			   <br/><br/>
			   <b>Total Adjusted Function Points:</b><xsl:text> </xsl:text><xsl:value-of select="$unAdjFp * $vaf"/>
             </xsl:if>			 
		  </body>
	   </html>
	</xsl:template>
	
	<xsl:template match="application">
	   <table>
	     <tr>
	        <td colspan="3"><font color="blue"><u>Application: <xsl:value-of select="@name"/></u></font></td>
	     </tr>
		 <xsl:call-template name="EmptyRow"/>
	     <xsl:apply-templates select="module"/>
	   </table>
	</xsl:template>
	
	<xsl:template match="module">
	   <tr>
	      <td colspan="3"><font color="green"><b>Module: <xsl:value-of select="@name"/></b></font></td>
	   </tr>
	   <tr>
	      <td>Data Function Point count</td>
		  <td>:</td>
		  <td><xsl:value-of select="fp:getDataFPCount(DataFunc)"/></td>
	   </tr>
	   <tr>
	      <td>Transaction Function Point count</td>
		  <td>:</td>
		  <td><xsl:value-of select="fp:getTxnFPCount(TxnFunc)"/></td>
	   </tr>
	   <xsl:call-template name="EmptyRow"/>
	</xsl:template>
	
</xsl:stylesheet>