<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="2.0" 
                xmlns:fp="http://example.org/fpCounting" 
				xmlns:xs="http://www.w3.org/2001/XMLSchema" exclude-result-prefixes="fp xs">
				
    <!--
       Generates Function Point report, for "enhancement" projects.
    -->	

    <xsl:output method="html"/>
	
	<xsl:include href="commonfp.xsl"/>
	
	<xsl:variable name="fpRefData" select="document('fpRefData.xml')/FPRefData"/>
	
	<!--
	    Main stylesheet template.
	-->
	<xsl:template match="FPCountingData">
	    <html>
	        <head>
		        <title>FP counting results</title>
		    </head>
		    <body>
		       <h2>Project: <xsl:value-of select="@project"/></h2>
			   <xsl:variable name="addedFuncResult">
			      <xsl:if test="AddedFunc">
			         <xsl:call-template name="FuncPointResultGroup">
				        <xsl:with-param name="txnNode" select="AddedFunc"/>
				     </xsl:call-template>
			      </xsl:if>
			   </xsl:variable>
			   <xsl:variable name="changedFuncResult">
			      <xsl:if test="ChangedFunc">
			         <xsl:call-template name="FuncPointResultGroup">
				        <xsl:with-param name="txnNode" select="ChangedFunc"/>
				     </xsl:call-template>
			      </xsl:if>
			   </xsl:variable>
			   <xsl:variable name="deletedFuncResult">
			      <xsl:if test="DeletedFunc">
			         <xsl:call-template name="FuncPointResultGroup">
				         <xsl:with-param name="txnNode" select="DeletedFunc"/>
				     </xsl:call-template>
			      </xsl:if>
               </xsl:variable>
               <xsl:copy-of select="$addedFuncResult, $changedFuncResult, $deletedFuncResult"/>
               <xsl:variable name="unAdjFp" select="fp:getTotalUnadjFPCount($addedFuncResult/table, $changedFuncResult/table, $deletedFuncResult/table)"/>
               <b>Total Unadjusted Function Points:</b><xsl:text> </xsl:text><xsl:value-of select="$unAdjFp"/>
               <xsl:if test="GSCA">
                  <br/><br/>
			      <xsl:variable name="vaf_after" select="(sum(GSCA/fact) * 0.01) + 0.65"/>
			      <b>New Value Adjustment Factor:</b><xsl:text> </xsl:text><xsl:value-of select="$vaf_after"/>
			      <br/><br/>
			      <b>Total Adjusted Function Points:</b><xsl:text> </xsl:text><xsl:value-of select="format-number((fp:getTotalUnadjFPCount($addedFuncResult/table, $changedFuncResult/table, ())
				                                                                                     * $vaf_after) +
																									(fp:getTotalUnadjFPCount((), (), $deletedFuncResult/table) * VAFB), '##.##')"/>
               </xsl:if>			   
		    </body>
		</html>
	</xsl:template>
	
	<!--
	   Calculate total Unadjusted Function point count.
	-->
	<xsl:function name="fp:getTotalUnadjFPCount" as="xs:double*">
	   <xsl:param name="addedFuncResult" as="element()?"/>
	   <xsl:param name="changedFuncResult" as="element()?"/>
	   <xsl:param name="deletedFuncResult" as="element()?"/>
	   
	   <xsl:sequence select="(if (exists($addedFuncResult)) then ($addedFuncResult/tr[2]/td[3] + $addedFuncResult/tr[3]/td[3]) else 0)
	                           +
							 (if (exists($changedFuncResult)) then ($changedFuncResult/tr[2]/td[3] + $changedFuncResult/tr[3]/td[3]) else 0)
							   +
							 (if (exists($deletedFuncResult)) then ($deletedFuncResult/tr[2]/td[3] + $deletedFuncResult/tr[3]/td[3]) else 0)"/>
	</xsl:function>
	
	<!--
	   Generates Function point counting results, for added, changed and deleted functionality.
	-->
	<xsl:template name="FuncPointResultGroup">
	   <xsl:param name="txnNode"/>
	   
	   <table>
	       <tr>
	          <td colspan="3"><font color="green"><b>Function points, for <xsl:value-of select="lower-case(substring-before(name($txnNode), 'Func'))"/> functionality:</b></font></td>
	       </tr>
	       <tr>
	          <td>Data Function Point count</td>
		      <td>:</td>
		      <td><xsl:value-of select="fp:getDataFPCount($txnNode/DataFunc)"/></td>
	       </tr>
	       <tr>
	          <td>Transaction Function Point count</td>
		      <td>:</td>
		      <td><xsl:value-of select="fp:getTxnFPCount($txnNode/TxnFunc)"/></td>
	       </tr>
	       <xsl:call-template name="EmptyRow"/>
	   </table>
	</xsl:template>
		
</xsl:stylesheet>	